/// <reference types="node" />
import { Buffer } from 'buffer';
import { FieldDescription, Uint, Uint64, NitroSigner } from '@cerc-io/nitro-util';
import { Bytes32 } from '@statechannels/nitro-protocol';
import { Signature } from '../crypto/signatures';
import { Destination } from '../types/destination';
import { Address } from '../types/types';
import { Funds } from '../types/funds';
import { Allocation } from './state/outcome/allocation';
import { SignedState } from './state/signedstate';
import { FixedPart, State, ConstructorOptions as FixedPartConstructorOptions } from './state/state';
import { ChainEvent } from '../node/engine/chainservice/chainservice';
import { Exit } from './state/outcome/exit';
interface ConstructorOptions extends FixedPartConstructorOptions {
    id?: Destination;
    myIndex?: Uint;
    onChain?: OnChainData;
    offChain?: OffChainData;
}
interface OnChainDataConstructorOptions {
    holdings?: Funds;
    outcome?: Exit;
    stateHash?: Bytes32;
}
interface OffChainDataConstructorOptions {
    signedStateForTurnNum?: Map<Uint64, SignedState>;
    latestSupportedStateTurnNum?: Uint64;
}
interface ChainUpdateData {
    blockNum: Uint64;
    txIndex: Uint;
}
declare class OnChainData {
    holdings: Funds;
    outcome: Exit;
    stateHash: Bytes32;
    constructor(params: OnChainDataConstructorOptions);
    static jsonEncodingMap: Record<string, FieldDescription>;
    static fromJSON(data: string): OnChainData;
    toJSON(): any;
}
declare class OffChainData {
    signedStateForTurnNum: Map<Uint64, SignedState>;
    latestSupportedStateTurnNum: Uint64;
    constructor(params: OffChainDataConstructorOptions);
    static jsonEncodingMap: Record<string, FieldDescription>;
    static fromJSON(data: string): OffChainData;
    toJSON(): any;
}
export declare class Channel extends FixedPart {
    id: Destination;
    myIndex: Uint;
    onChain: OnChainData;
    offChain: OffChainData;
    lastChainUpdate: ChainUpdateData;
    static jsonEncodingMap: Record<string, FieldDescription>;
    static fromJSON(data: string): Channel;
    toJSON(): any;
    constructor(params: ConstructorOptions);
    isNewChainEvent(event: ChainEvent): boolean;
    static new(s: State, myIndex: Uint): Channel;
    marshalJSON(): Buffer;
    unmarshalJSON(): void;
    myDestination(): Destination;
    clone(): Channel;
    preFundState(): State;
    signedPreFundState(): SignedState;
    postFundState(): State;
    signedPostFundState(): SignedState;
    preFundSignedByMe(): boolean;
    postFundSignedByMe(): boolean;
    preFundComplete(): boolean;
    postFundComplete(): boolean;
    finalSignedByMe(): boolean;
    finalCompleted(): boolean;
    hasSupportedState(): boolean;
    latestSupportedState(): State;
    latestSignedState(): SignedState;
    total(): Funds;
    affords(allocationMap: Map<Address, Allocation>, fundingMap: Funds): boolean;
    addStateWithSignature(s: State, sig: Signature): boolean;
    addSignedState(ss: SignedState): boolean;
    signAndAddPrefund(signer: NitroSigner): Promise<SignedState>;
    signAndAddPostfund(signer: NitroSigner): Promise<SignedState>;
    signAndAddState(s: State, signer: NitroSigner): Promise<SignedState>;
    updateWithChainEvent(event: ChainEvent): Channel;
}
export {};
