import type { ReadChannel } from '@cerc-io/ts-channel';
import { Uint64, Uint } from '@cerc-io/nitro-util';
import { Bytes32 } from '@statechannels/nitro-protocol';
import { ChainTransaction, Objective } from '../../../protocols/interfaces';
import { Address } from '../../../types/types';
import { Destination } from '../../../types/destination';
import { FixedPart, VariablePart } from '../../../channel/state/state';
import { Signature } from '../../../crypto/signatures';
import { Exit } from '../../../channel/state/outcome/exit';
import { SignedState } from '../../../channel/state/signedstate';
export interface ChainEvent {
    channelID(): Destination;
    blockNum(): Uint64;
    txIndex(): Uint;
}
interface CommonEventConstructorOptions {
    _channelID?: Destination;
    _blockNum?: Uint64;
    _txIndex?: Uint;
}
declare class CommonEvent implements ChainEvent {
    private _channelID;
    _blockNum: bigint;
    _txIndex: bigint;
    constructor(params: CommonEventConstructorOptions);
    channelID(): Destination;
    blockNum(): Uint64;
    txIndex(): Uint;
}
interface AssetAndAmountConstructorOptions {
    assetAddress?: Address;
    assetAmount?: bigint;
}
declare class AssetAndAmount {
    assetAddress: Address;
    assetAmount?: bigint;
    constructor(params: AssetAndAmountConstructorOptions);
    string(): string;
}
export declare class DepositedEvent extends CommonEvent {
    nowHeld?: bigint;
    asset: Address;
    constructor(params: {
        nowHeld?: bigint;
        asset: Address;
    } & CommonEventConstructorOptions);
    static newDepositedEvent(channelId: Destination, blockNum: Uint64, txIndex: Uint64, assetAddress: Address, nowHeld?: bigint): DepositedEvent;
    string(): string;
}
export interface ChainEventHandler {
    updateWithChainEvent(event: ChainEvent): Objective;
}
export interface ChainService {
    eventFeed(): ReadChannel<ChainEvent>;
    sendTransaction(tx: ChainTransaction): Promise<void>;
    getConsensusAppAddress(): Address;
    getVirtualPaymentAppAddress(): Address;
    getChainId(): Promise<bigint>;
    getLastConfirmedBlockNum(): Promise<Uint64>;
    close(): Promise<void>;
}
export declare class ConcludedEvent extends CommonEvent {
    string(): string;
}
export declare class ChallengeRegisteredEvent extends CommonEvent {
    canditate?: VariablePart;
    candidateSignatures?: Signature[];
    constructor(params: {
        canditate: VariablePart;
        candidateSignatures: Signature[];
    } & CommonEventConstructorOptions);
    static NewChallengeRegisteredEvent(channelId: Destination, blockNum: Uint64, txIndex: Uint64, variablePart: VariablePart, sigs: Signature[]): ChallengeRegisteredEvent;
    stateHash(fp: FixedPart): Bytes32;
    outcome(): Exit;
    SignedState(fp: FixedPart): SignedState;
    string(): string;
}
export declare class AllocationUpdatedEvent extends CommonEvent {
    assetAndAmount: AssetAndAmount;
    string(): string;
    static newAllocationUpdatedEvent(channelId: Destination, blockNum: Uint64, txIndex: Uint64, assetAddress: Address, assetAmount: bigint | undefined): AllocationUpdatedEvent;
    constructor(params: CommonEventConstructorOptions, assetAndAmountParams: AssetAndAmountConstructorOptions);
}
export {};
