import { ethers, providers } from 'ethers';
import debug from 'debug';
import { WaitGroup } from '@jpwilliams/waitgroup';
import type { ReadChannel, ReadWriteChannel } from '@cerc-io/ts-channel';
import { EthClient, Context, Uint64 } from '@cerc-io/nitro-util';
import { ChainService, ChainEvent } from './chainservice';
import { ChainTransaction } from '../../../protocols/interfaces';
import { Address } from '../../../types/types';
import { NitroAdjudicator } from './adjudicator/nitro-adjudicator';
import { EventTracker } from './event-queue';
export interface ChainOpts {
    chainUrl?: string;
    chainStartBlock: Uint64;
    chainPk?: string;
    provider?: providers.JsonRpcProvider;
    naAddress: Address;
    vpaAddress: Address;
    caAddress: Address;
}
interface EthChain extends EthClient {
    chainID(): Promise<bigint>;
}
export declare class EthChainService implements ChainService {
    private chain;
    private na;
    private naAddress;
    private consensusAppAddress;
    private virtualPaymentAppAddress;
    private txSigner;
    private out;
    private logger;
    private ctx;
    private cancel;
    private wg?;
    private eventTracker;
    private eventUnsubscribe?;
    private newBlockUnsubscribe?;
    private errorUnsubscribe?;
    constructor(chain: EthChain, na: NitroAdjudicator, naAddress: string, consensusAppAddress: string, virtualPaymentAppAddress: string, txSigner: ethers.Signer, out: ReadWriteChannel<ChainEvent>, logger: debug.Debugger, ctx: Context, cancel: () => void, wg: WaitGroup, eventTracker: EventTracker, eventUnsubscribe?: () => void, newBlockUnsubscribe?: () => void, errorUnsubscribe?: () => void);
    static newEthChainService(chainOpts: ChainOpts): Promise<ChainService>;
    private static _newEthChainService;
    private checkForMissedEvents;
    private listenForSubscriptionError;
    private listenForErrors;
    private defaultTxOpts;
    sendTransaction(tx: ChainTransaction): Promise<void>;
    private dispatchChainEvents;
    private listenForEventLogs;
    private listenForNewBlocks;
    private updateEventTracker;
    private subscribeForLogs;
    eventFeed(): ReadChannel<ChainEvent>;
    getConsensusAppAddress(): Address;
    getVirtualPaymentAppAddress(): Address;
    getChainId(): Promise<bigint>;
    getLastConfirmedBlockNum(): Promise<Uint64>;
    close(): Promise<void>;
}
export {};
