import { providers } from 'ethers';
import type { Peer } from '@cerc-io/peer';
import { NitroSigner, Context } from '@cerc-io/nitro-util';
import { Node } from '../node/node';
import { P2PMessageService } from '../node/engine/messageservice/p2p-message-service/service';
import { Store } from '../node/engine/store/store';
import { ChannelStatus, LedgerChannelInfo, PaymentChannelInfo } from '../node/query/types';
import { ChainService } from '../node/engine/chainservice/chainservice';
import { Voucher } from '../payments/vouchers';
import { MetricsApi } from '../node/engine/metrics';
export declare class Nitro {
    node: Node;
    msgService: P2PMessageService;
    chainService: ChainService;
    nitroSigner: NitroSigner;
    store: Store;
    asset: string;
    constructor(node: Node, msgService: P2PMessageService, chainService: ChainService, nitroSigner: NitroSigner, store: Store, asset?: string);
    static setupNode(pk: string, chainURL: string, chainPk: string, contractAddresses: {
        [key: string]: string;
    }, peer: Peer, useDurableStore: boolean, durableStoreFolder?: string, metricsApi?: MetricsApi, asset?: string, chainStartBlock?: number): Promise<Nitro>;
    static setupNodeWithProvider(provider: providers.Web3Provider, snapOrigin: string, contractAddresses: {
        [key: string]: string;
    }, peer: Peer, useDurableStore: boolean, durableStoreFolder?: string, metricsApi?: MetricsApi, asset?: string, chainStartBlock?: number): Promise<Nitro>;
    static clearNodeStorage(): Promise<boolean>;
    addPeerByMultiaddr(address: string, multiaddrString: string): Promise<void>;
    isPeerDialable(address: string): Promise<[boolean, string]>;
    directFund(counterParty: string, amount: string): Promise<string>;
    virtualFund(counterParty: string, amount: string, intermediaries?: string[]): Promise<string>;
    pay(virtualPaymentChannel: string, amount: string): Promise<Voucher>;
    virtualDefund(virtualPaymentChannel: string): Promise<void>;
    directDefund(ledgerChannel: string): Promise<void>;
    getLedgerChannel(ledgerChannel: string): Promise<LedgerChannelInfo>;
    getAllLedgerChannels(): Promise<LedgerChannelInfo[]>;
    getPaymentChannel(paymentChannel: string): Promise<PaymentChannelInfo>;
    getPaymentChannelsByLedger(ledgerChannel: string): Promise<PaymentChannelInfo[]>;
    waitForPaymentChannelStatus(channelId: string, status: ChannelStatus, ctx: Context): Promise<void>;
    waitForLedgerChannelStatus(channelId: string, status: ChannelStatus, ctx: Context): Promise<void>;
    onPaymentChannelUpdated(channelId: string, callback: (info: PaymentChannelInfo) => void, ctx: Context): Promise<void>;
    close(): Promise<void>;
}
